.. _spec_v3:

Zarr Storage Specification Version 3
=======================================================

The V3 Specification has been migrated to its website →
https://zarr-specs.readthedocs.io/.
